@@ -77,7 +77,7 @@ utils::globalVariables(c("silentText","silentGraph","silentLegend","initialType"
 auto.ssarima <- function(data, orders=list(ar=c(3,3),i=c(2,1),ma=c(3,3)), lags=c(1,frequency(data)),
                          combine=FALSE, workFast=TRUE, constant=NULL,
                          initial=c("backcasting","optimal"), ic=c("AICc","AIC","BIC"),
-                         cfType=c("MSE","MAE","HAM","MSEh","TMSE","GTMSE"),
+                         cfType=c("MSE","MAE","HAM","MSEh","TMSE","GTMSE","MSCE"),
                          h=10, holdout=FALSE, cumulative=FALSE,
                          intervals=c("none","parametric","semiparametric","nonparametric"), level=0.95,
                          intermittent=c("none","auto","fixed","interval","probability","sba"), imodel="MNN",
