@@ -192,7 +192,7 @@ utils::globalVariables(c("normalizer","constantValue","constantRequired","consta
 ssarima <- function(data, orders=list(ar=c(0),i=c(1),ma=c(1)), lags=c(1),
                     constant=FALSE, AR=NULL, MA=NULL,
                     initial=c("backcasting","optimal"), ic=c("AICc","AIC","BIC"),
-                    cfType=c("MSE","MAE","HAM","MSEh","TMSE","GTMSE"),
+                    cfType=c("MSE","MAE","HAM","MSEh","TMSE","GTMSE","MSCE"),
                     h=10, holdout=FALSE, cumulative=FALSE,
                     intervals=c("none","parametric","semiparametric","nonparametric"), level=0.95,
                     intermittent=c("none","auto","fixed","interval","probability","sba","logistic"),
