@@ -28,7 +28,7 @@ test_that("Test initials, measurement, transition and persistence of GES on N256
 # Test exogenous (normal + updateX) with GES
 x <- cbind(c(rep(0,25),1,rep(0,43)),c(rep(0,10),1,rep(0,58)));
 y <- ts(c(Mcomp::M3$N1457$x,Mcomp::M3$N1457$xx),frequency=12);
-testModel <- ges(y, h=18, holdout=TRUE, xreg=x, updateX=TRUE, silent=TRUE, cfType="aMSTFE", intervals="np")
+testModel <- ges(y, h=18, holdout=TRUE, xreg=x, updateX=TRUE, silent=TRUE, cfType="aTMSE", intervals="np")
 test_that("Check exogenous variables for GESX on N1457", {
     expect_equal(suppressWarnings(ges(y, h=18, holdout=TRUE, xreg=x, silent=TRUE)$model), testModel$model);
     expect_equal(suppressWarnings(forecast(testModel, h=18, holdout=FALSE)$method), testModel$model);
